##  Importing and Exporting Fact Sheets
You can import and export data as spreadsheets into and from your inventory. This feature is particularly useful for populating your inventory in the initial stage and for efficiently performing bulk updates on your fact sheets. The options for importing and exporting data are accessed from the Inventory Tools menu at the top.
For more information about importing and exporting fact sheets, refer to [Exporting Fact Sheet Data as Excel File](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s export feature allows you to export fact sheet data as an Excel file for bulk updates, easy data manipulation, and offline analysis. The exported file also serves as a template for importing data back into SAP LeanIX.") and [Importing Fact Sheet Data through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
